@@ -1,7 +1,7 @@
 package Perinci::Object;
 
-our $DATE = '2014-10-20'; # DATE
-our $VERSION = '0.15'; # VERSION
+our $DATE = '2014-10-28'; # DATE
+our $VERSION = '0.16'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,7 +9,7 @@ use warnings;
 
 require Exporter;
 our @ISA    = qw(Exporter);
-our @EXPORT = qw(rimeta risub rivar ripkg envres riresmeta);
+our @EXPORT = qw(rimeta risub rivar ripkg envres envresmulti riresmeta);
 
 sub rimeta {
     require Perinci::Object::Metadata;
@@ -36,6 +36,11 @@ sub envres {
     Perinci::Object::EnvResult->new(@_);
 }
 
+sub envresmulti {
+    require Perinci::Object::EnvResultMulti;
+    Perinci::Object::EnvResultMulti->new(@_);
+}
+
 sub riresmeta {
     require Perinci::Object::ResMeta;
     Perinci::Object::ResMeta->new(@_);
@@ -56,12 +61,12 @@ Perinci::Object - Object-oriented interface for Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.15 of Perinci::Object (from Perl distribution Perinci-Object), released on 2014-10-20.
+This document describes version 0.16 of Perinci::Object (from Perl distribution Perinci-Object), released on 2014-10-28.
 
 =head1 SYNOPSIS
 
  use Perinci::Object; # automatically exports risub(), rivar(), ripkg(),
-                      # envres(), riresmeta()
+                      # envres(), envresmulti(), riresmeta()
  use Data::Dump; # for dd()
 
  # OO interface to function metadata.
@@ -140,6 +145,10 @@ Exported by default. A shortcut for Perinci::Object::Package->new($meta).
 
 Exported by default. A shortcut for Perinci::Object::EnvResult->new($res).
 
+=head2 envresmulti $res => OBJECT
+
+Exported by default. A shortcut for Perinci::Object::EnvResultMulti->new($res).
+
 =head2 riresmeta $resmeta => OBJECT
 
 Exported by default. A shortcut for Perinci::Object::ResMeta->new($res).
